@@ -26,6 +26,9 @@
 
 #include "gnome-vfs-configuration.h"
 #include "gnome-vfs-private.h"
+#ifdef G_OS_WIN32
+#include "gnome-vfs-private-utils.h"
+#endif
 #include <gmodule.h>
 #include <libgnomevfs/gnome-vfs-module.h>
 #include <libgnomevfs/gnome-vfs-transform.h>
@@ -52,18 +55,24 @@ typedef struct _ModuleElement ModuleElement;
 static gboolean method_already_initialized = FALSE;
 
 static gboolean gnome_vfs_is_daemon = FALSE;
+static GType daemon_volume_monitor_type = 0;
+static void (*daemon_force_probe_callback) (GnomeVFSVolumeMonitor *volume_monitor) = NULL;
 
 static GHashTable *module_hash = NULL;
 G_LOCK_DEFINE_STATIC (gnome_vfs_method_init);
-GStaticRecMutex module_hash_lock = G_STATIC_REC_MUTEX_INIT;
+static GStaticRecMutex module_hash_lock = G_STATIC_REC_MUTEX_INIT;
 
 static GList *module_path_list = NULL;
 
-
+/* Pass some integration stuff here, so we can make the library not depend
+   on the daemon-side code */
 void
-gnome_vfs_set_is_daemon (void)
+gnome_vfs_set_is_daemon (GType volume_monitor_type,
+			 GnomeVFSDaemonForceProbeCallback force_probe_callback)
 {
 	gnome_vfs_is_daemon = TRUE;
+	daemon_volume_monitor_type = volume_monitor_type;
+	daemon_force_probe_callback = force_probe_callback;
 }
 
 gboolean
@@ -72,6 +81,18 @@ gnome_vfs_get_is_daemon (void)
 	return gnome_vfs_is_daemon;
 }
 
+GType
+_gnome_vfs_get_daemon_volume_monitor_type (void)
+{
+	return daemon_volume_monitor_type;
+}
+
+GnomeVFSDaemonForceProbeCallback
+_gnome_vfs_get_daemon_force_probe_callback (void)
+{
+	return daemon_force_probe_callback;
+}
+
 static gboolean
 init_hash_table (void)
 {
@@ -91,7 +112,7 @@ install_path_list (const gchar *user_path_list)
 	while (1) {
 		gchar *elem;
 
-		p = strchr (oldp, ':');
+		p = strchr (oldp, G_SEARCHPATH_SEPARATOR);
 
 		if (p == NULL) {
 			if (*oldp != '\0') {
@@ -133,7 +154,9 @@ init_path_list (void)
 	/* Default path.  It comes last so that users can override it.  */
 
 	module_path_list = g_list_append (module_path_list,
-					  g_strdup (GNOME_VFS_MODULE_DIR));
+					  g_build_filename (GNOME_VFS_LIBDIR,
+							    GNOME_VFS_MODULE_SUBDIR,
+							    NULL));
 
 	return TRUE;
 }
@@ -283,8 +306,12 @@ gnome_vfs_add_module_to_hash_table (const gchar *name)
 	GnomeVFSTransform *transform = NULL;
 	ModuleElement *module_element;
 	const char *module_name;
-	pid_t saved_uid;
+#if defined (HAVE_SETEUID) || defined (HAVE_SETRESUID)
+	uid_t saved_uid;
+#endif
+#if defined (HAVE_SETEGID) || defined (HAVE_SETRESGID)
 	gid_t saved_gid;
+#endif
 	const char *args;
 	gboolean run_in_daemon;
 
@@ -303,8 +330,12 @@ gnome_vfs_add_module_to_hash_table (const gchar *name)
 		/* Set the effective UID/GID to the user UID/GID to prevent attacks to
 		   setuid/setgid executables.  */
 		
+#if defined (HAVE_SETEUID) || defined (HAVE_SETRESUID)
 		saved_uid = geteuid ();
+#endif
+#if defined (HAVE_SETEGID) || defined (HAVE_SETRESGID)
 		saved_gid = getegid ();
+#endif
 #if defined(HAVE_SETEUID)
 		seteuid (getuid ());
 #elif defined(HAVE_SETRESUID)
